@@ -22,11 +22,14 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_GMICSTDLIB_H_
-#define _GMIC_QT_GMICSTDLIB_H_
+#ifndef GMIC_QT_GMICSTDLIB_H
+#define GMIC_QT_GMICSTDLIB_H
 
 #include <QByteArray>
 
+namespace GmicQt
+{
+
 class GmicStdLib {
 public:
   GmicStdLib() = delete;
@@ -34,4 +37,6 @@ public:
   static QByteArray Array;
 };
 
-#endif // _GMIC_QT_GMICSTDLIB_H_
+} // namespace GmicQt
+
+#endif // GMIC_QT_GMICSTDLIB_H
