@@ -26,22 +26,22 @@
 #define GMIC_QT_IMAGETOOLS_H
 
 #include "Common.h"
-#include "PreviewMode.h"
+#include "GmicQt.h"
 
 namespace cimg_library
 {
 template <typename T> struct CImg;
 template <typename T> struct CImgList;
-}
+} // namespace cimg_library
 
 namespace GmicQt
 {
-template <typename T> void image2uchar(cimg_library::CImg<T> & img);
-template <typename T> void calibrate_image(cimg_library::CImg<T> & img, const int spectrum, const bool is_preview);
 
-void buildPreviewImage(const cimg_library::CImgList<float> & images, cimg_library::CImg<float> & result, GmicQt::PreviewMode previewMode, int previewWidth, int previewHeight);
-}
+bool checkImageSpectrumAtMost4(const cimg_library::CImgList<float> & images, unsigned int & index);
+void buildPreviewImage(const cimg_library::CImgList<float> & images, cimg_library::CImg<float> & result);
 
 template <typename T> bool hasAlphaChannel(const cimg_library::CImg<T> & image);
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_IMAGETOOLS_H
